@@ -16,11 +16,11 @@ class PlugBoleto(object):
         return request.execute(criar_boleto)
 
     def consulta_boleto(self, id_integracao):
-        request = BuscaBoleto(self.merchant, self.environment)
+        request = BuscaBoleto(self.authorize, self.environment)
 
         return request.execute(id_integracao)
 
-    def link_boleto(self, empresa, id_integracao):
-        uri = 'https://plugboleto.com.br/impresao/%s1/%s' % (empresa, id_integracao)
+    def link_boleto(self, id_integracao):
+        uri = '%sboletos/impressao/%s' % (self.environment.api, id_integracao)
 
         return uri
\ No newline at end of file
