@@ -14,9 +14,9 @@ class Base(object):
         body = data
 
         headers = {
-            'cnpj-sh': self.cnpjsh,
-            'token-sh': self.tokensh,
-            'cnpj-cedente': self.cnpjcedente
+            'cnpj-sh': self.authorize.cnpjsh,
+            'token-sh': self.authorize.tokensh,
+            'cnpj-cedente': self.authorize.cnpjcedente
         }
 
         if not body:
@@ -53,3 +53,34 @@ class Base(object):
             ''.join(errors), method, response.url, json.dumps(data_send, indent=2)))
 
         return answers
+
+    def request_numerodoc(self, method, uri):
+
+        s = Session()
+
+        req = Request(method, uri)
+
+        prep = s.prepare_request(req)
+
+        response = s.send(prep)
+
+        if 'json' in response.headers['Content-Type'].lower():
+            answers = response.json()
+        else:
+            answers = [{
+                'Code': str(response.status_code),
+                'Message': response.text
+            }]
+
+        if response.status_code >= 400:
+            errors = []
+
+            for answer in answers:
+                errors.append('\r\n * [%s] %s\r\n' % (answer['Code'], answer['Message']))
+
+            data_send = json.loads(body or 'null')
+
+            raise Exception('\r\n%s\r\nMethod: %s\r\nUri: %s\r\nData: %s' % (
+            ''.join(errors), method, response.url, json.dumps(data_send, indent=2)))
+
+        return answers
