@@ -11,10 +11,14 @@ class CriarBoleto(Base):
 
     def execute(self, criar_boleto):
 
-        uri = '%s1/boletos/lote' % self.environment.api
+        uri = '%sboletos/lote' % self.environment.api
 
         response = self.send_request("POST", uri, criar_boleto)
 
-        criar_boleto.update_return(response)
+        sucesso = response['_dados']['_sucesso']
+        if sucesso:
+            criar_boleto.update_return(response)
+        else:
+            return response['_dados']['_falha'][0]
 
         return response
